@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,29 +16,34 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.resourcemanager_v3.services.projects import pagers
-from google.cloud.resourcemanager_v3.types import projects
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import ProjectsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ProjectsGrpcAsyncIOTransport
+
+from google.cloud.resourcemanager_v3.services.projects import pagers
+from google.cloud.resourcemanager_v3.types import projects
+
 from .client import ProjectsClient
+from .transports.base import DEFAULT_CLIENT_INFO, ProjectsTransport
+from .transports.grpc_asyncio import ProjectsGrpcAsyncIOTransport
 
 
 class ProjectsAsyncClient:
@@ -101,6 +106,42 @@ class ProjectsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ProjectsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ProjectsTransport:
         """Returns the transport used by the client instance.
@@ -176,6 +217,25 @@ class ProjectsAsyncClient:
         The caller must have ``resourcemanager.projects.get`` permission
         for this project.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_get_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.GetProjectRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_project(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.GetProjectRequest, dict]):
                 The request object. The request sent to the
@@ -203,7 +263,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -243,7 +303,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -265,6 +330,26 @@ class ProjectsAsyncClient:
         caller must have ``resourcemanager.projects.list`` permission on
         the identified parent.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_list_projects():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.ListProjectsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_projects(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.ListProjectsRequest, dict]):
                 The request object. The request sent to the
@@ -304,7 +389,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -338,12 +423,20 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListProjectsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -372,6 +465,25 @@ class ProjectsAsyncClient:
         [GetProject][google.cloud.resourcemanager.v3.Projects.GetProject]
         method.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_search_projects():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.SearchProjectsRequest(
+                )
+
+                # Make the request
+                page_result = client.search_projects(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.SearchProjectsRequest, dict]):
                 The request object. The request sent to the
@@ -384,36 +496,37 @@ class ProjectsAsyncClient:
                 query, the it will return results that match any of the
                 fields. Some eligible fields are:
 
-                \| Field \| Description \|
-                \|-------------------------\|----------------------------------------------\|
-                \| displayName, name \| Filters by displayName. \| \|
-                parent \| Project's parent. (for example: folders/123,
-                organizations/*) Prefer parent field over parent.type
-                and parent.id. \| \| parent.type \| Parent's type:
-                ``folder`` or ``organization``. \| \| parent.id \|
-                Parent's id number (for example: 123) \| \| id,
-                projectId \| Filters by projectId. \| \| state,
-                lifecycleState \| Filters by state. \| \| labels \|
-                Filters by label name or value. \| \| labels. (where
-                *key* is the name of a label) \| Filters by label name.
-                \|
+                ::
+
+                   | Field                   | Description                                  |
+                   |-------------------------|----------------------------------------------|
+                   | displayName, name       | Filters by displayName.                      |
+                   | parent                  | Project's parent. (for example: folders/123,
+                   organizations/*) Prefer parent field over parent.type and parent.id. |
+                   | parent.type             | Parent's type: `folder` or `organization`.   |
+                   | parent.id               | Parent's id number (for example: 123)        |
+                   | id, projectId           | Filters by projectId.                        |
+                   | state, lifecycleState   | Filters by state.                            |
+                   | labels                  | Filters by label name or value.              |
+                   | labels.<key> (where *key* is the name of a label) | Filters by label
+                   name. |
 
                 Search expressions are case insensitive.
 
                 Some examples queries:
 
-                \| Query \| Description \|
-                \|------------------\|-----------------------------------------------------\|
-                \| name:how\* \| The project's name starts with "how".
-                \| \| name:Howl \| The project's name is ``Howl`` or
-                ``howl``. \| \| name:HOWL \| Equivalent to above. \| \|
-                NAME:howl \| Equivalent to above. \| \| labels.color:\*
-                \| The project has the label ``color``. \| \|
-                labels.color:red \| The project's label ``color`` has
-                the value ``red``. \| \|
-                labels.color:red labels.size:big \| The project's label
-                ``color`` has the value ``red`` and its label ``size``
-                has the value ``big``. \|
+                ::
+
+                   | Query            | Description                                         |
+                   |------------------|-----------------------------------------------------|
+                   | name:how*        | The project's name starts with "how".               |
+                   | name:Howl        | The project's name is `Howl` or `howl`.             |
+                   | name:HOWL        | Equivalent to above.                                |
+                   | NAME:howl        | Equivalent to above.                                |
+                   | labels.color:*   | The project has the label `color`.                  |
+                   | labels.color:red | The project's label `color` has the value `red`.    |
+                   | labels.color:red&nbsp;labels.size:big | The project's label `color` has
+                   the value `red` and its label `size` has the value `big`.                |
 
                 If no query is specified, the call will return projects
                 for which the user has the
@@ -443,7 +556,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([query])
         if request is not None and has_flattened_params:
@@ -468,12 +581,20 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.SearchProjectsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -495,6 +616,28 @@ class ProjectsAsyncClient:
         after a few hours, so there is no need to call
         ``DeleteOperation``.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_create_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.CreateProjectRequest(
+                )
+
+                # Make the request
+                operation = client.create_project(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.CreateProjectRequest, dict]):
                 The request object. The request sent to the
@@ -531,7 +674,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project])
         if request is not None and has_flattened_params:
@@ -556,7 +699,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -587,6 +735,28 @@ class ProjectsAsyncClient:
         The caller must have ``resourcemanager.projects.update``
         permission for this project.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_update_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.UpdateProjectRequest(
+                )
+
+                # Make the request
+                operation = client.update_project(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.UpdateProjectRequest, dict]):
                 The request object. The request sent to the
@@ -627,7 +797,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project, update_mask])
         if request is not None and has_flattened_params:
@@ -662,7 +832,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -698,6 +873,30 @@ class ProjectsAsyncClient:
         ``resourcemanager.projects.move`` permission on the project's
         current and proposed new parent.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_move_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.MoveProjectRequest(
+                    name="name_value",
+                    destination_parent="destination_parent_value",
+                )
+
+                # Make the request
+                operation = client.move_project(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.MoveProjectRequest, dict]):
                 The request object. The request sent to
@@ -733,7 +932,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, destination_parent])
         if request is not None and has_flattened_params:
@@ -766,7 +965,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -824,6 +1028,29 @@ class ProjectsAsyncClient:
         The caller must have ``resourcemanager.projects.delete``
         permissions for this project.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_delete_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.DeleteProjectRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_project(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.DeleteProjectRequest, dict]):
                 The request object. [DeleteProject][google.cloud.resourcemanager.v3.Projects.DeleteProject]
@@ -851,7 +1078,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -882,7 +1109,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -913,6 +1145,29 @@ class ProjectsAsyncClient:
         The caller must have ``resourcemanager.projects.undelete``
         permission for this project.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_undelete_project():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.UndeleteProjectRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.undelete_project(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.UndeleteProjectRequest, dict]):
                 The request object. The request sent to the
@@ -944,7 +1199,7 @@ class ProjectsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -975,7 +1230,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1001,6 +1261,26 @@ class ProjectsAsyncClient:
         specified project. Permission is denied if the policy or
         the resource do not exist.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
+
+            async def sample_get_iam_policy():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = iam_policy_pb2.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = await client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -1022,21 +1302,26 @@ class ProjectsAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1051,17 +1336,17 @@ class ProjectsAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1072,15 +1357,16 @@ class ProjectsAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -1094,7 +1380,9 @@ class ProjectsAsyncClient:
         if isinstance(request, dict):
             request = iam_policy_pb2.GetIamPolicyRequest(**request)
         elif not request:
-            request = iam_policy_pb2.GetIamPolicyRequest(resource=resource,)
+            request = iam_policy_pb2.GetIamPolicyRequest(
+                resource=resource,
+            )
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1120,7 +1408,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1187,6 +1480,26 @@ class ProjectsAsyncClient:
         -  Calling this method requires enabling the App Engine Admin
            API.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
+
+            async def sample_set_iam_policy():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = iam_policy_pb2.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = await client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -1208,21 +1521,26 @@ class ProjectsAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1237,17 +1555,17 @@ class ProjectsAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1258,15 +1576,16 @@ class ProjectsAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -1280,7 +1599,9 @@ class ProjectsAsyncClient:
         if isinstance(request, dict):
             request = iam_policy_pb2.SetIamPolicyRequest(**request)
         elif not request:
-            request = iam_policy_pb2.SetIamPolicyRequest(resource=resource,)
+            request = iam_policy_pb2.SetIamPolicyRequest(
+                resource=resource,
+            )
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1297,7 +1618,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1315,6 +1641,27 @@ class ProjectsAsyncClient:
         r"""Returns permissions that a caller has on the
         specified project.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
+
+            async def sample_test_iam_permissions():
+                # Create a client
+                client = resourcemanager_v3.ProjectsAsyncClient()
+
+                # Initialize request argument(s)
+                request = iam_policy_pb2.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = await client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
@@ -1348,7 +1695,7 @@ class ProjectsAsyncClient:
                 Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource, permissions])
         if request is not None and has_flattened_params:
@@ -1363,7 +1710,8 @@ class ProjectsAsyncClient:
             request = iam_policy_pb2.TestIamPermissionsRequest(**request)
         elif not request:
             request = iam_policy_pb2.TestIamPermissionsRequest(
-                resource=resource, permissions=permissions,
+                resource=resource,
+                permissions=permissions,
             )
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1381,7 +1729,12 @@ class ProjectsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
