@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,26 +16,31 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+
 from google.cloud.resourcemanager_v3.services.tag_bindings import pagers
 from google.cloud.resourcemanager_v3.types import tag_bindings
-from google.protobuf import empty_pb2  # type: ignore
-from .transports.base import TagBindingsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import TagBindingsGrpcAsyncIOTransport
+
 from .client import TagBindingsClient
+from .transports.base import DEFAULT_CLIENT_INFO, TagBindingsTransport
+from .transports.grpc_asyncio import TagBindingsGrpcAsyncIOTransport
 
 
 class TagBindingsAsyncClient:
@@ -105,6 +110,42 @@ class TagBindingsAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return TagBindingsClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> TagBindingsTransport:
         """Returns the transport used by the client instance.
@@ -181,6 +222,26 @@ class TagBindingsAsyncClient:
         name:
         https://cloud.google.com/apis/design/resource_names#full_resource_name
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_list_tag_bindings():
+                # Create a client
+                client = resourcemanager_v3.TagBindingsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.ListTagBindingsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_tag_bindings(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.ListTagBindingsRequest, dict]):
                 The request object. The request message to list all
@@ -209,7 +270,7 @@ class TagBindingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -243,12 +304,20 @@ class TagBindingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListTagBindingsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -266,6 +335,28 @@ class TagBindingsAsyncClient:
         r"""Creates a TagBinding between a TagValue and a cloud
         resource (currently project, folder, or organization).
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_create_tag_binding():
+                # Create a client
+                client = resourcemanager_v3.TagBindingsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.CreateTagBindingRequest(
+                )
+
+                # Make the request
+                operation = client.create_tag_binding(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.CreateTagBindingRequest, dict]):
                 The request object. The request message to create a
@@ -295,7 +386,7 @@ class TagBindingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([tag_binding])
         if request is not None and has_flattened_params:
@@ -320,7 +411,12 @@ class TagBindingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -344,6 +440,29 @@ class TagBindingsAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a TagBinding.
 
+        .. code-block:: python
+
+            from google.cloud import resourcemanager_v3
+
+            async def sample_delete_tag_binding():
+                # Create a client
+                client = resourcemanager_v3.TagBindingsAsyncClient()
+
+                # Initialize request argument(s)
+                request = resourcemanager_v3.DeleteTagBindingRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_tag_binding(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.resourcemanager_v3.types.DeleteTagBindingRequest, dict]):
                 The request object. The request message to delete a
@@ -382,7 +501,7 @@ class TagBindingsAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -413,7 +532,12 @@ class TagBindingsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
