@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.resourcemanager.v3",
@@ -87,7 +85,7 @@ class Project(proto.Message):
             resource. This may be sent on update and delete
             requests to ensure the client has an up-to-date
             value before proceeding.
-        labels (Sequence[google.cloud.resourcemanager_v3.types.Project.LabelsEntry]):
+        labels (Mapping[str, str]):
             Optional. The labels associated with this project.
 
             Label keys must be between 1 and 63 characters long and must
@@ -114,16 +112,51 @@ class Project(proto.Message):
         ACTIVE = 1
         DELETE_REQUESTED = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    parent = proto.Field(proto.STRING, number=2,)
-    project_id = proto.Field(proto.STRING, number=3,)
-    state = proto.Field(proto.ENUM, number=4, enum=State,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
-    delete_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
-    etag = proto.Field(proto.STRING, number=9,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=10,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    project_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=State,
+    )
+    display_name = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    delete_time = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message=timestamp_pb2.Timestamp,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=10,
+    )
 
 
 class GetProjectRequest(proto.Message):
@@ -137,7 +170,10 @@ class GetProjectRequest(proto.Message):
             ``projects/415104041262``).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListProjectsRequest(proto.Message):
@@ -168,10 +204,22 @@ class ListProjectsRequest(proto.Message):
             projects are returned.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_token = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    show_deleted = proto.Field(proto.BOOL, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    show_deleted = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
 
 
 class ListProjectsResponse(proto.Message):
@@ -210,8 +258,15 @@ class ListProjectsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    projects = proto.RepeatedField(proto.MESSAGE, number=1, message="Project",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    projects = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Project",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class SearchProjectsRequest(proto.Message):
@@ -227,34 +282,37 @@ class SearchProjectsRequest(proto.Message):
             return results that match any of the fields. Some eligible
             fields are:
 
-            \| Field \| Description \|
-            \|-------------------------\|----------------------------------------------\|
-            \| displayName, name \| Filters by displayName. \| \| parent
-            \| Project's parent. (for example: folders/123,
-            organizations/*) Prefer parent field over parent.type and
-            parent.id. \| \| parent.type \| Parent's type: ``folder`` or
-            ``organization``. \| \| parent.id \| Parent's id number (for
-            example: 123) \| \| id, projectId \| Filters by projectId.
-            \| \| state, lifecycleState \| Filters by state. \| \|
-            labels \| Filters by label name or value. \| \| labels.
-            (where *key* is the name of a label) \| Filters by label
-            name. \|
+            ::
+
+               | Field                   | Description                                  |
+               |-------------------------|----------------------------------------------|
+               | displayName, name       | Filters by displayName.                      |
+               | parent                  | Project's parent. (for example: folders/123,
+               organizations/*) Prefer parent field over parent.type and parent.id. |
+               | parent.type             | Parent's type: `folder` or `organization`.   |
+               | parent.id               | Parent's id number (for example: 123)        |
+               | id, projectId           | Filters by projectId.                        |
+               | state, lifecycleState   | Filters by state.                            |
+               | labels                  | Filters by label name or value.              |
+               | labels.<key> (where *key* is the name of a label) | Filters by label
+               name. |
 
             Search expressions are case insensitive.
 
             Some examples queries:
 
-            \| Query \| Description \|
-            \|------------------\|-----------------------------------------------------\|
-            \| name:how\* \| The project's name starts with "how". \| \|
-            name:Howl \| The project's name is ``Howl`` or ``howl``. \|
-            \| name:HOWL \| Equivalent to above. \| \| NAME:howl \|
-            Equivalent to above. \| \| labels.color:\* \| The project
-            has the label ``color``. \| \| labels.color:red \| The
-            project's label ``color`` has the value ``red``. \| \|
-            labels.color:red labels.size:big \| The project's label
-            ``color`` has the value ``red`` and its label ``size`` has
-            the value ``big``. \|
+            ::
+
+               | Query            | Description                                         |
+               |------------------|-----------------------------------------------------|
+               | name:how*        | The project's name starts with "how".               |
+               | name:Howl        | The project's name is `Howl` or `howl`.             |
+               | name:HOWL        | Equivalent to above.                                |
+               | NAME:howl        | Equivalent to above.                                |
+               | labels.color:*   | The project has the label `color`.                  |
+               | labels.color:red | The project's label `color` has the value `red`.    |
+               | labels.color:red&nbsp;labels.size:big | The project's label `color` has
+               the value `red` and its label `size` has the value `big`.                |
 
             If no query is specified, the call will return projects for
             which the user has the ``resourcemanager.projects.get``
@@ -271,9 +329,18 @@ class SearchProjectsRequest(proto.Message):
             server picks an appropriate default.
     """
 
-    query = proto.Field(proto.STRING, number=1,)
-    page_token = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
+    query = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
 
 
 class SearchProjectsResponse(proto.Message):
@@ -309,8 +376,15 @@ class SearchProjectsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    projects = proto.RepeatedField(proto.MESSAGE, number=1, message="Project",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    projects = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Project",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CreateProjectRequest(proto.Message):
@@ -332,7 +406,11 @@ class CreateProjectRequest(proto.Message):
             parent will be set to that Organization.
     """
 
-    project = proto.Field(proto.MESSAGE, number=1, message="Project",)
+    project = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Project",
+    )
 
 
 class CreateProjectMetadata(proto.Message):
@@ -353,9 +431,19 @@ class CreateProjectMetadata(proto.Message):
             complete.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    gettable = proto.Field(proto.BOOL, number=2,)
-    ready = proto.Field(proto.BOOL, number=3,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    gettable = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
+    ready = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
 
 
 class UpdateProjectRequest(proto.Message):
@@ -376,9 +464,15 @@ class UpdateProjectRequest(proto.Message):
             update fields.
     """
 
-    project = proto.Field(proto.MESSAGE, number=1, message="Project",)
+    project = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Project",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -402,8 +496,14 @@ class MoveProjectRequest(proto.Message):
             under.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    destination_parent = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    destination_parent = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class MoveProjectMetadata(proto.Message):
@@ -423,7 +523,10 @@ class DeleteProjectRequest(proto.Message):
             ``projects/415104041262``).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteProjectMetadata(proto.Message):
@@ -445,7 +548,10 @@ class UndeleteProjectRequest(proto.Message):
             Required.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UndeleteProjectMetadata(proto.Message):
